@@ -1,5 +1,5 @@
 from manager_client.manager_client import ManagerClient
-from client_utils import ClientUtils
+from client_utils.client_utils import ClientUtils
 
 
 class MiddlewareClient:
